@@ -19,11 +19,7 @@ class JacApi:
         """
         Command line tooling for building executable jac ir
         """
-        if not os.path.isfile(file):
-            ret = "File does not exsist!"
-            return ret
-        filename = os.path.basename(file)
-        dir = os.path.dirname(os.path.realpath(file))
+        filename, dir = self.check_for_file(file)
         if not len(out):
             if file.endswith(".jac"):
                 out = file.replace(".jac", ".jir")
@@ -45,17 +41,37 @@ class JacApi:
 
                 return ret
 
+    @Interface.cli_api(cli_args=["file"])
+    def jac_disas(self, file: str):
+        """
+        Command line tooling for print IR for both .jac code files
+        and .jir executables
+        """
+        filename, dir = self.check_for_file(file)
+        is_jir = file.endswith(".jir")
+        faux = self.faux_master()
+        with open(file, "r") as file:
+            if is_jir:
+                faux.sentinel_register(name=filename)
+                ret = faux.sentinel_set(
+                    snt=faux.active_snt(), code=file.read(), mode="ir"
+                )
+                faux.active_snt().print_ir()
+            else:
+                ret = faux.sentinel_register(
+                    code=file.read(), code_dir=dir, name=filename, auto_run=""
+                )
+                faux.active_snt().print_ir()
+            if "success" in ret and not ret["success"]:
+                return ret
+
     @Interface.cli_api(cli_args=["file"])
     def jac_test(self, file: str, detailed: bool = False):
         """
         Command line tooling for running all test in both .jac code files
         and .jir executables
         """
-        if not os.path.isfile(file):
-            ret = "File does not exsist!"
-            return ret
-        filename = os.path.basename(file)
-        dir = os.path.dirname(os.path.realpath(file))
+        filename, dir = self.check_for_file(file)
         is_jir = file.endswith(".jir")
         faux = self.faux_master()
         with open(file, "r") as file:
@@ -78,11 +94,7 @@ class JacApi:
         Command line tooling for running all test in both .jac code files
         and .jir executables
         """
-        if not os.path.isfile(file):
-            ret = "File does not exsist!"
-            return ret
-        filename = os.path.basename(file)
-        dir = os.path.dirname(os.path.realpath(file))
+        filename, dir = self.check_for_file(file)
         is_jir = file.endswith(".jir")
         faux = self.faux_master()
         with open(file, "r") as file:
@@ -111,11 +123,7 @@ class JacApi:
         Command line tooling for a walker then output graph in both .jac code
         files and .jir executables
         """
-        if not os.path.isfile(file):
-            ret = "File does not exsist!"
-            return ret
-        filename = os.path.basename(file)
-        dir = os.path.dirname(os.path.realpath(file))
+        filename, dir = self.check_for_file(file)
         is_jir = file.endswith(".jir")
         faux = self.faux_master()
         with open(file, "r") as file:
@@ -141,3 +149,11 @@ class JacApi:
         faux = MetaService().build_super_master()
         faux._h.mem["global"] = deepcopy(self._h.mem["global"])
         return faux
+
+    def check_for_file(self, file):
+        if not os.path.isfile(file):
+            ret = "File does not exsist!"
+            return ret
+        filename = os.path.basename(file)
+        dir = os.path.dirname(os.path.realpath(file))
+        return filename, dir
