@@ -4,11 +4,14 @@ Mix in for jac code object in Jaseci
 import json
 from jaseci.utils.utils import logger
 from jaseci.jac.ir.ast_builder import JacAstBuilder
+from jaseci.jac.ir.passes.schedule import multi_pass_optimizer
 from jaseci.jac.ir.ast import Ast
 import hashlib
 from pathlib import Path
 from os.path import dirname
 
+from jaseci.jac.ir.passes.printer_pass import PrinterPass
+
 # Used to check ir matches grammar of current Jaseci instance
 grammar_hash = hashlib.md5(
     Path(dirname(__file__) + "/../jac.g4").read_text().encode()
@@ -98,25 +101,43 @@ class JacCode:
         self.code_sig = hashlib.md5(self.code_ir.encode()).hexdigest()
         JacCode.refresh(self)  # should disregard overloaded versions
 
-    def parse_jac(self, code, dir, start_rule="start"):
+    def compile_jac(self, code, dir, start_rule="start", opt_level=4):
         """Generate AST tree from Jac code text"""
         tree = JacAstBuilder(
             jac_text=code, start_rule=start_rule, mod_name=self.name, mod_dir=dir
         )
+        # Must clear this state across compiles (so fresh imports dont use stale data)
+        JacAstBuilder._ast_head_map = {}
+
+        multi_pass_optimizer(
+            tree.root, opt_level=opt_level
+        )  # run analysis and optimizers
+
         self.errors = tree._parse_errors
         if tree._parse_errors:
             logger.error(str(f"{self.name}: Invalid syntax in Jac code!"))
             for i in tree._parse_errors:
                 logger.error(i)
             return None
+
         return tree.root
 
+    def get_jac_ast(self):
+        if not self._jac_ast:
+            self.refresh()
+        return self._jac_ast
+
+    def print_ir(self, to_screen=True):
+        irout = PrinterPass(ir=self.get_jac_ast(), to_screen=to_screen)
+        irout.run()
+        return irout.output
+
     def register(self, code, dir):
         """
         Parses Jac code and saves IR
         """
         start_rule = "start" if self.j_type == "sentinel" else self.j_type
-        tree = self.parse_jac(code, dir, start_rule=start_rule)
+        tree = self.compile_jac(code, dir, start_rule=start_rule)
 
         if not tree:
             self.is_active = False
